.. _configuration:

=============
Configuration
=============

The following is a sample ``nova_dpm.conf`` configuration file for the nova-dpm
driver, for adaptation and use.

It is auto-generated from the nova-dpm project when this documentation is
built, so if you are having issues with an option, please compare your version
of the ``nova-dpm`` Python package with the version of this documentation.

The sample configuration can also be viewed in
`file form <_static/nova_dpm.conf.sample>`_.

.. literalinclude:: _static/nova_dpm.conf.sample
